summaryrefslogtreecommitdiff
path: root/vcl/source/gdi/gdimetafiletools.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2016-09-20 16:41:39 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2016-10-05 06:51:20 +0000
commit954f752cf10fc6a8777af2a6a93e496688464687 (patch)
tree0fc776cdcb6ad9b1d2b9673ac044bb5b4f496972 /vcl/source/gdi/gdimetafiletools.cxx
parentc1e18e05a53c1d55afe36a887ca25f74f3f1d32d (diff)
convert MapUnit to scoped enum
I left a prefix on the names "Map" so that I would not have to re-arrange each name too much, since I can't start identifiers with digits like "100thMM" And remove RSC_EXTRAMAPUNIT, which doesn't seem to be doing anything anymore. Change-Id: I5187824aa87e30caf5357b51b5384b5ab919d224 Reviewed-on: https://gerrit.libreoffice.org/29096 Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk> Tested-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'vcl/source/gdi/gdimetafiletools.cxx')
-rw-r--r--vcl/source/gdi/gdimetafiletools.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/vcl/source/gdi/gdimetafiletools.cxx b/vcl/source/gdi/gdimetafiletools.cxx
index b8adfdf18109..877ca9a302f1 100644
--- a/vcl/source/gdi/gdimetafiletools.cxx
+++ b/vcl/source/gdi/gdimetafiletools.cxx
@@ -276,7 +276,7 @@ void clipMetafileContentAgainstOwnRegions(GDIMetaFile& rSource)
// start with empty region
aClips.push_back(basegfx::B2DPolyPolygon());
// start with default MapMode (MAP_PIXEL)
aMapModes.push_back(MapMode());
for(sal_uLong i(0); i < nObjCount; ++i)
@@ -715,7 +715,7 @@ void clipMetafileContentAgainstOwnRegions(GDIMetaFile& rSource)
// combination with the current MapMode
Size aLogicalSize(rBitmapEx.GetPrefSize());
- if(MAP_PIXEL == rBitmapEx.GetPrefMapMode().GetMapUnit())
+ if(MapUnit::MapPixel == rBitmapEx.GetPrefMapMode().GetMapUnit())
{
aLogicalSize = Application::GetDefaultDevice()->PixelToLogic(aLogicalSize, aMapModes.back().GetMapUnit());
}
@@ -742,7 +742,7 @@ void clipMetafileContentAgainstOwnRegions(GDIMetaFile& rSource)
// combination with the current MapMode
Size aLogicalSize(rBitmap.GetPrefSize());
- if(MAP_PIXEL == rBitmap.GetPrefMapMode().GetMapUnit())
+ if(MapUnit::MapPixel == rBitmap.GetPrefMapMode().GetMapUnit())
{
aLogicalSize = Application::GetDefaultDevice()->PixelToLogic(aLogicalSize, aMapModes.back().GetMapUnit());
}
@@ -276,7 +276,7 @@ void clipMetafileContentAgainstOwnRegions(GDIMetaFile& rSource)
// start with empty region
aClips.push_back(basegfx::B2DPolyPolygon());
- // start with default MapMode (MAP_PIXEL)
+ // start with default MapMode (MapUnit::MapPixel)
aMapModes.push_back(MapMode());
for(sal_uLong i(0); i < nObjCount; ++i)